@@ -65,8 +65,7 @@ class Authenticator(object):
 
         self.login_session_id = self.request.cookies.get('__sl__', None)
         if not self.login_session_id:
-            self.login_session_id = uuid4()
-            self.request.response.setCookie('__sl__', self.login_session_id)
+            self.set_login_session_id()
 
         self.valid_flow_states = [
             self.REQUESTING_AUTH_CODE,
@@ -116,6 +115,10 @@ class Authenticator(object):
                 })
         return auth_schemes
 
+    def set_login_session_id(self):
+        self.login_session_id = uuid4()
+        self.request.response.setCookie('__sl__', self.login_session_id)
+
     def get_secure_flow_key(self):
         return '{id}-secure-state'.format(id=self.login_session_id)
 
@@ -147,6 +150,7 @@ class Authenticator(object):
             cache.delete(key)
         except Exception:
             pass
+        self.set_login_session_id()
 
     def authorize_2factor(self, username, code, offset=0):
         if not code:
@@ -185,7 +189,7 @@ class Authenticator(object):
 
     def authenticate(self, username=None, password=None,
                      country=None, login=True):
-        """return true if successfull
+        """return true if successful
         login: if a successful authentication should result in the user being
                logged in
         """
@@ -310,16 +314,23 @@ class Authenticator(object):
             if (came_from.startswith(site_url) and (
                     not url_tool or url_tool.isURLInPortal(came_from))):
                 success_url = came_from
-            if 'login' in success_url or 'logged_out' in success_url \
-                    or 'manage' in success_url:
-                success_url = site_url + '/@@dashboard'
+            if 'login' in success_url or 'logged_out' in success_url:
+                if ISiteRoot.providedBy(self.context):
+                    success_url = site_url + '/@@dashboard'
+                else:
+                    success_url = site_url  # zope root
+            elif 'manage' in success_url:
+                if ISiteRoot.providedBy(self.context):
+                    success_url = site_url + '/@@dashboard'
+                # else zope root, allow /manage here
 
         data = {
             'supportedAuthSchemes': self.get_supported_auth_schemes(),
             'twoFactorEnabled': self.two_factor_enabled,
             'apiEndpoint': '{}/@@secure-login'.format(site_url),
             'successUrl': success_url,
-            'additionalProviders': []
+            'additionalProviders': [],
+            'state': self.get_secure_flow_state()
         }
         try:
             data['authenticator'] = createToken()
